// Output generated from file: /home/toonfish/Fragmentarium/Menger_Sphere.frag
// Created: Sat Dec 3 11:59:38 2016
// Output generated from file: Fragmentarium/Knighty Collection/Menger_Sphere.frag
// Created: Fri Dec 2 22:48:24 2016
// http://www.fractalforums.com/programming/project-a-cube-into-a-sphere-%28not-riemann%27s-way%29/
#info Menger Distance Estimator.
#define providesInit
#include "DE-Kn2.frag"
#include "MathUtils.frag"
#group Menger
// Bailout
uniform float Bailout;   slider[0.,100.,200.]
// Cube or Sphere
uniform bool Sphere; checkbox[true]
// Number of iterations.
uniform int Iterations;  slider[0,10,20]

// Scale parameter. A perfect Menger is 3.0
uniform float Scale; slider[0.00,3,4.00]

uniform vec3 RotVector; slider[(0,0,0),(1,0,0),(1,1,1)]

// Scale parameter. A perfect Menger is 3.0
uniform float RotAngle; slider[0.00,00,360]

// Scaling center
uniform vec3 Offset; slider[(-5,-5,-5),(1,1,1),(5,5,5)]
uniform vec3 fo; slider[(0.,0,0),(0.5,0.5,0.5),(2.,2.,2.)]
uniform vec3 g; slider[(0.,0,0),(0.1,0.1,0.1),(2.,2.,2.)]
uniform bool Serial; checkbox[false]
// coordinate to invert to infinity
uniform vec3 InvertC; slider[(-15,-15,-15),(0,0,0),(15,15,15)]

mat3 rot;
float sc,sr;
void init() {
	rot = rotationMatrix3(normalize(RotVector), RotAngle);
	vec3 o=abs(Offset);
	sc = max(o.x,max(o.y,o.z));
	sr=sqrt(dot(o,o)+1.);
}
// Roqen's domain mashup performs the active c = T(s)
vec3 domainMap(vec3 c)
{
  float s = dot(c,c);
  return (c/s) *- InvertC;
}
//DarkBeam's "fold"... reinterpreted... it's more than a fold, much more! Just awesome!
float DBFold(vec3 p, float fo, float g){
	if(p.z>p.y) p.yz=p.zy;//Diagonal fold
	//Tis is slightly different from the original fold in order to make it continuous in this context
	float vx=p.x-2.*fo;
	float vy=p.y-4.*fo;
 	float v=max(abs(vx+fo)-fo,vy);
	float v1=max(vx-g,p.y);
	v=min(v,v1);
	return min(v,p.x);
}
//the coordinates are pushed/pulled in parallel
vec3 DBFoldParallel(vec3 p, vec3 fo, vec3 g){
	vec3 p1=p;
	p.x=DBFold(p1,fo.x,g.x);
	p.y=DBFold(p1.yzx,fo.y,g.y);
	p.z=DBFold(p1.zxy,fo.z,g.z);
	return p;
}
//serial version
vec3 DBFoldSerial(vec3 p, vec3 fo, vec3 g){
	p.x=DBFold(p,fo.x,g.x);
	p.y=DBFold(p.yzx,fo.y,g.y);
	p.z=DBFold(p.zxy,fo.z,g.z);
	return p;
}

float DE(vec3 p)
{
	float dd;
if(Sphere) {
	vec3 ap=abs(p);
	float Linf=max(max(ap.x,ap.y),ap.z);//infinity norm
	float L2=length(p);//euclidean norm
	float multiplier=L2/Linf;
	p*=multiplier;//Spherify transform.
	dd=multiplier*1.6;//to correct the DE. Found by try and error. there should be better formula.
} else {
	dd=1.;
}
		//Apply pull transformation
		vec3 signs=sign(p);//Save 	the original signs
		p=abs(p);
		if(Serial) p=DBFoldSerial(p,fo,g);
		else p=DBFoldParallel(p,fo,g);
		p*=signs;//resore signs: this way the mandelbrot set won't extend in negative directions
	float r2=dot(p,p);
	for(int i = 0; i<Iterations && r2<Bailout; i++){
     p += domainMap(-p);
		p=abs(p);
		if(p.y>p.x) p.xy=p.yx;
		if(p.z>p.y) p.yz=p.zy;
  		if(p.y>p.x) p.xy=p.yx;
		p.z=abs(p.z-1./3.*Offset.z)+1./3.*Offset.z;
		p=p*Scale-Offset*(Scale-1.); dd*=Scale;
		p=rot*p;
		r2=dot(p,p);
		orbitTrap = min(orbitTrap, abs(vec4(p.x,p.y,p.z,r2)));
	}
if(Sphere) {
	return (sqrt(r2)-sr)/dd;//bounding volume is a sphere
} else {
	p=abs(p);
   return (max(p.x,max(p.y,p.z))-sc)/dd;//bounding volume is a cube
}
}



#preset Default
FOV = 0.62536
Eye = -4.487192,-4.280184,-6.042053
Target = -4.291819,-3.97896,-5.061222
Up = 0.5421977,0.5096043,-0.2645061
EquiRectangular = false
Gamma = 2
ToneMapping = 1
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 6
AntiAliasScale = 1.5
DepthToAlpha = false
Detail = -5
FudgeFactor = 0.1
Dither = 1
NormalBackStep = 1
CamLight = 1,1,1,1
Glow = 1,1,1,0
GlowMax = 20
BaseColor = 1,1,1
OrbitStrength = 0.7887324
X = 1,1,1,-0.045045
Y = 0.345098,0.666667,0,0.6727273
Z = 1,0.666667,0,0.3333333
R = 0.0784314,1,0.941176,-0.0642202
BackgroundColor = 0.607843,0.866667,0.560784
GradientBackground = 0.8
CycleColors = true
Cycles = 2.1
EnableFloor = false
FloorNormal = 0,0,0
FloorColor = 1,1,1
Bailout = 30.49485
Sphere = false
Iterations = 8
Scale = 3
RotVector = 0,1,0
RotAngle = 26.34146
Offset = 2.256637,2.168142,1.371681
fo = 2,1.777778,0
g = 0.2972973,0.5405405,1.337838
Serial = true
AutoFocus = false
FocalPlane = 1
Aperture = 0
InFocusAWidth = 0
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
LensFlare = false
FlareIntensity = 0.25
FlareSamples = 8
FlareDispersal = 0.25
FlareHaloWidth = 0.5
FlareDistortion = 1
RefineSteps = 4
MaxRaySteps = 1024
MaxDistance = 1000
DetailAO = -2
coneApertureAO = 0.5
maxIterAO = 20
FudgeAO = 1
AO_ambient = 1
AO_camlight = 1
AO_pointlight = 1
AoCorrect = 0
Specular = 0.4
SpecularExp = 16
AmbiantLight = 1,1,1,1
Reflection = 1,1,1
ReflectionsNumber = 0
SpotGlow = false
SpotLight = 1,1,1,20
LightPos = 30,-4.772727,-30
LightSize = 0.1
LightFallOff = 0
LightGlowRad = 0
LightGlowExp = 1
HardShadow = 0
ShadowSoft = 10
FloorHeight = 0
HF_Fallof = 0.1
HF_Const = 0
HF_Intensity = 0
HF_Dir = 0,0,1
HF_Offset = 0
HF_Color = 1,1,1,1
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 1
HF_CastShadow = false
CloudScale = 1
CloudFlatness = 0
CloudTops = 1
CloudBase = -1
CloudDensity = 1
CloudRoughness = 1
CloudContrast = 1
CloudColor = 0.65,0.68,0.7
SunLightColor = 0.7,0.5,0.3
WindDir = 0,0,1
WindSpeed = 1
InvertC = -5.285714,-0.3061224,-0.3061224
#endpreset

#preset Structures1
FOV = 0.62536
Eye = -4.744992,-4.137569,-7.79492
Target = -4.22213,-3.927189,-6.91555
Up = -0.0423742,0.772259,-0.1595595
EquiRectangular = false
Gamma = 2
ToneMapping = 1
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 6
AntiAliasScale = 1.5
DepthToAlpha = false
Detail = -5
FudgeFactor = 0.1
Dither = 1
NormalBackStep = 1
CamLight = 1,1,1,1
Glow = 1,1,1,0
GlowMax = 20
BaseColor = 1,1,1
OrbitStrength = 0.7887324
X = 1,1,1,-0.045045
Y = 0.345098,0.666667,0,0.6727273
Z = 1,0.666667,0,0.3333333
R = 0.0784314,1,0.941176,-0.0642202
BackgroundColor = 0.607843,0.866667,0.560784
GradientBackground = 0.8
CycleColors = true
Cycles = 2.1
EnableFloor = false
FloorNormal = 0,0,0
FloorColor = 1,1,1
Bailout = 26.80412
Sphere = false
Iterations = 8
Scale = 2.942149
RotVector = 0,0,1
RotAngle = 45
Offset = 2.256637,3.168142,2.371681
fo = 2,1.819444,1
g = 1,1,1
Serial = true
AutoFocus = false
FocalPlane = 1
Aperture = 0
InFocusAWidth = 0
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
LensFlare = false
FlareIntensity = 0.25
FlareSamples = 8
FlareDispersal = 0.25
FlareHaloWidth = 0.5
FlareDistortion = 1
RefineSteps = 4
MaxRaySteps = 2048
MaxDistance = 1000
DetailAO = -2
coneApertureAO = 0.5
maxIterAO = 20
FudgeAO = 1
AO_ambient = 1
AO_camlight = 1
AO_pointlight = 1
AoCorrect = 0
Specular = 0.4
SpecularExp = 16
AmbiantLight = 1,1,1,1
Reflection = 1,1,1
ReflectionsNumber = 0
SpotGlow = false
SpotLight = 1,1,1,20
LightPos = 30,-4.772727,-30
LightSize = 0.1
LightFallOff = 0
LightGlowRad = 0
LightGlowExp = 1
HardShadow = 0
ShadowSoft = 10
FloorHeight = 0
HF_Fallof = 0.1
HF_Const = 0
HF_Intensity = 0
HF_Dir = 0,0,1
HF_Offset = 0
HF_Color = 1,1,1,1
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 1
HF_CastShadow = false
CloudScale = 1
CloudFlatness = 0
CloudTops = 1
CloudBase = -1
CloudDensity = 1
CloudRoughness = 1
CloudContrast = 1
CloudColor = 0.65,0.68,0.7
SunLightColor = 0.7,0.5,0.3
WindDir = 0,0,1
WindSpeed = 1
InvertC = -2.285714,-1.306122,-3
#endpreset

#preset Structures2
FOV = 0.62536
Eye = 2.934615,-2.718216,-5.778298
Target = 2.766888,-2.593533,-4.795765
Up = -0.5204171,0.5688741,-0.1610296
EquiRectangular = false
Gamma = 2
ToneMapping = 1
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 6
AntiAliasScale = 1.5
DepthToAlpha = false
Detail = -5
FudgeFactor = 0.1
Dither = 1
NormalBackStep = 1
CamLight = 1,1,1,1
Glow = 1,1,1,0
GlowMax = 20
BaseColor = 1,1,1
OrbitStrength = 0.8309859
X = 1,1,1,-0.2972973
Y = 0.345098,0.666667,0,0.4909091
Z = 1,0.666667,0,0.3333333
R = 0.0784314,1,0.941176,0.0091743
BackgroundColor = 0.02745098,0.02745098,0.0627451
GradientBackground = 0
CycleColors = true
Cycles = 22.27547
EnableFloor = false
FloorNormal = 0,0,0
FloorColor = 1,1,1
Bailout = 26.80412
Sphere = true
Iterations = 8
Scale = 2.942149
RotVector = 0,0,1
RotAngle = 45
Offset = 2.256637,3.168142,2.371681
fo = 2,1.819444,1
g = 1,1,1
Serial = true
AutoFocus = false
FocalPlane = 1
Aperture = 0
InFocusAWidth = 0
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
LensFlare = false
FlareIntensity = 0.25
FlareSamples = 8
FlareDispersal = 0.25
FlareHaloWidth = 0.5
FlareDistortion = 1
RefineSteps = 4
MaxRaySteps = 2048
MaxDistance = 1000
DetailAO = -2
coneApertureAO = 0.5
maxIterAO = 20
FudgeAO = 1
AO_ambient = 1
AO_camlight = 1
AO_pointlight = 1
AoCorrect = 0
Specular = 0.4
SpecularExp = 16
AmbiantLight = 1,1,1,1
Reflection = 1,1,1
ReflectionsNumber = 0
SpotGlow = false
SpotLight = 1,1,1,20
LightPos = 30,-4.772727,-30
LightSize = 0.1
LightFallOff = 0
LightGlowRad = 0
LightGlowExp = 1
HardShadow = 0
ShadowSoft = 10
FloorHeight = 0
HF_Fallof = 0.1
HF_Const = 0
HF_Intensity = 0
HF_Dir = 0,0,1
HF_Offset = 0
HF_Color = 1,1,1,1
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 1
HF_CastShadow = false
CloudScale = 1
CloudFlatness = 0
CloudTops = 1
CloudBase = -1
CloudDensity = 1
CloudRoughness = 1
CloudContrast = 1
CloudColor = 0.65,0.68,0.7
SunLightColor = 0.7,0.5,0.3
WindDir = 0,0,1
WindSpeed = 1
InvertC = -2.285714,-1.306122,-3
#endpreset

#preset Structures3
FOV = 0.62536
Eye = 1.38078,-1.305885,-4.513204
Target = 0.865707,-0.8637366,-3.772763
Up = -0.3831481,0.4399012,-0.5292132
EquiRectangular = false
Gamma = 2
ToneMapping = 1
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 6
AntiAliasScale = 1.5
DepthToAlpha = false
Detail = -5
FudgeFactor = 0.1
Dither = 1
NormalBackStep = 1
CamLight = 1,1,1,1
Glow = 1,1,1,0
GlowMax = 20
BaseColor = 1,1,1
OrbitStrength = 0.8309859
X = 1,1,1,-0.2972973
Y = 0.345098,0.666667,0,0.4909091
Z = 1,0.666667,0,0.3333333
R = 0.0784314,1,0.941176,0.0091743
BackgroundColor = 0.02745098,0.02745098,0.0627451
GradientBackground = 0
CycleColors = true
Cycles = 22.27547
EnableFloor = false
FloorNormal = 0,0,0
FloorColor = 1,1,1
Bailout = 39.17526
Sphere = true
Iterations = 10
Scale = 2.942149
RotVector = 0,0,1
RotAngle = 45
Offset = 2.256637,3.168142,2.371681
fo = 2,1.819444,1
g = 1,1,1
Serial = true
AutoFocus = false
FocalPlane = 1
Aperture = 0
InFocusAWidth = 0
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
LensFlare = false
FlareIntensity = 0.25
FlareSamples = 8
FlareDispersal = 0.25
FlareHaloWidth = 0.5
FlareDistortion = 1
RefineSteps = 4
MaxRaySteps = 2048
MaxDistance = 1000
DetailAO = -2
coneApertureAO = 0.5
maxIterAO = 20
FudgeAO = 1
AO_ambient = 1
AO_camlight = 1
AO_pointlight = 1
AoCorrect = 0
Specular = 0.4
SpecularExp = 16
AmbiantLight = 1,1,1,1
Reflection = 1,1,1
ReflectionsNumber = 0
SpotGlow = false
SpotLight = 1,1,1,20
LightPos = 30,-4.772727,-30
LightSize = 0.1
LightFallOff = 0
LightGlowRad = 0
LightGlowExp = 1
HardShadow = 0
ShadowSoft = 10
FloorHeight = 0
HF_Fallof = 0.1
HF_Const = 0
HF_Intensity = 0
HF_Dir = 0,0,1
HF_Offset = 0
HF_Color = 1,1,1,1
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 1
HF_CastShadow = false
CloudScale = 1
CloudFlatness = 0
CloudTops = 1
CloudBase = -1
CloudDensity = 1
CloudRoughness = 1
CloudContrast = 1
CloudColor = 0.65,0.68,0.7
SunLightColor = 0.7,0.5,0.3
WindDir = 0,0,1
WindSpeed = 1
InvertC = -2.285714,-1.306122,-3
#endpreset

#preset Structures4
FOV = 0.62536
Eye = 4.67695,-1.847397,2.85348
Target = 4.02554,-1.501143,2.171701
Up = 0.5994638,0.2175728,-0.462263
EquiRectangular = false
Gamma = 2
ToneMapping = 1
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 6
AntiAliasScale = 1.5
DepthToAlpha = false
Detail = -5
FudgeFactor = 0.1
Dither = 1
NormalBackStep = 1
CamLight = 1,1,1,1
Glow = 1,1,1,0
GlowMax = 20
BaseColor = 1,1,1
OrbitStrength = 0.8309859
X = 1,1,1,-0.2972973
Y = 0.345098,0.666667,0,0.4909091
Z = 1,0.666667,0,0.3333333
R = 0.0784314,1,0.941176,0.0091743
BackgroundColor = 0.02745098,0.02745098,0.0627451
GradientBackground = 0
CycleColors = true
Cycles = 22.27547
EnableFloor = false
FloorNormal = 0,0,0
FloorColor = 1,1,1
Bailout = 8.247422
Sphere = false
Iterations = 2
Scale = 3.471074
RotVector = 0,1,0
RotAngle = 0
Offset = 1.106195,0.6637168,1.19469
fo = 1.041667,0.9861111,0.9861111
g = 0.4864865,2,2
Serial = true
AutoFocus = false
FocalPlane = 1
Aperture = 0
InFocusAWidth = 0
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
LensFlare = false
FlareIntensity = 0.25
FlareSamples = 8
FlareDispersal = 0.25
FlareHaloWidth = 0.5
FlareDistortion = 1
RefineSteps = 4
MaxRaySteps = 2048
MaxDistance = 1000
DetailAO = -2
coneApertureAO = 0.5
maxIterAO = 20
FudgeAO = 1
AO_ambient = 1
AO_camlight = 1
AO_pointlight = 1
AoCorrect = 0
Specular = 0.4
SpecularExp = 16
AmbiantLight = 1,1,1,1
Reflection = 1,1,1
ReflectionsNumber = 0
SpotGlow = false
SpotLight = 1,1,1,20
LightPos = 30,-6.136364,30
LightSize = 0.1
LightFallOff = 0
LightGlowRad = 0
LightGlowExp = 1
HardShadow = 0
ShadowSoft = 10
FloorHeight = 0
HF_Fallof = 0.1
HF_Const = 0
HF_Intensity = 0
HF_Dir = 0,0,1
HF_Offset = 0
HF_Color = 1,1,1,1
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 1
HF_CastShadow = false
CloudScale = 1
CloudFlatness = 0
CloudTops = 1
CloudBase = -1
CloudDensity = 1
CloudRoughness = 1
CloudContrast = 1
CloudColor = 0.65,0.68,0.7
SunLightColor = 0.7,0.5,0.3
WindDir = 0,0,1
WindSpeed = 1
InvertC = 0,0,0
#endpreset

#preset Structures5
FOV = 0.1889764
Eye = 3.428709,-3.161034,5.506559
Target = 3.060044,-2.657617,4.719344
Up = 0.7313372,0.1153011,-0.2687628
EquiRectangular = false
Gamma = 2
ToneMapping = 1
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 6
AntiAliasScale = 1.5
DepthToAlpha = false
Detail = -5
FudgeFactor = 0.1
Dither = 1
NormalBackStep = 1
CamLight = 1,1,1,1
Glow = 1,1,1,0
GlowMax = 20
BaseColor = 1,1,1
OrbitStrength = 0.8309859
X = 1,1,1,-0.2972973
Y = 0.345098,0.666667,0,0.4909091
Z = 1,0.666667,0,0.3333333
R = 0.0784314,1,0.941176,0.0091743
BackgroundColor = 0.02745098,0.02745098,0.0627451
GradientBackground = 0
CycleColors = true
Cycles = 22.27547
EnableFloor = false
FloorNormal = 0,0,0
FloorColor = 1,1,1
Bailout = 8.247422
Sphere = false
Iterations = 2
Scale = 3.471074
RotVector = 0,1,0
RotAngle = 0
Offset = 1.19469,0.4867257,1.19469
fo = 0.125,0.7222222,1.027778
g = 0.6351351,0.4594595,0.3918919
Serial = false
AutoFocus = false
FocalPlane = 1
Aperture = 0
InFocusAWidth = 0
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
LensFlare = false
FlareIntensity = 0.25
FlareSamples = 8
FlareDispersal = 0.25
FlareHaloWidth = 0.5
FlareDistortion = 1
RefineSteps = 4
MaxRaySteps = 2048
MaxDistance = 1000
DetailAO = -2
coneApertureAO = 0.5
maxIterAO = 20
FudgeAO = 1
AO_ambient = 1
AO_camlight = 1
AO_pointlight = 1
AoCorrect = 0
Specular = 0.4
SpecularExp = 16
AmbiantLight = 1,1,1,1
Reflection = 1,1,1
ReflectionsNumber = 0
SpotGlow = false
SpotLight = 1,1,1,20
LightPos = 30,-6.136364,30
LightSize = 0.1
LightFallOff = 0
LightGlowRad = 0
LightGlowExp = 1
HardShadow = 0
ShadowSoft = 10
FloorHeight = 0
HF_Fallof = 0.1
HF_Const = 0
HF_Intensity = 0
HF_Dir = 0,0,1
HF_Offset = 0
HF_Color = 1,1,1,1
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 1
HF_CastShadow = false
CloudScale = 1
CloudFlatness = 0
CloudTops = 1
CloudBase = -1
CloudDensity = 1
CloudRoughness = 1
CloudContrast = 1
CloudColor = 0.65,0.68,0.7
SunLightColor = 0.7,0.5,0.3
WindDir = 0,0,1
WindSpeed = 1
InvertC = 0,0.3061224,0
#endpreset

#preset Structures6
AutoFocus = false
FOV = 0.5354331
Eye = -2.6785,2.472631,0.0242512
Target = -1.907808,1.746941,-0.086433
Up = -0.3570897,-0.3822321,0.0196568
EquiRectangular = false
FocalPlane = 1
Aperture = 0
InFocusAWidth = 0
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Gamma = 1
ToneMapping = 1
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 1
AntiAliasScale = 1.5
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
LensFlare = false
FlareIntensity = 0.25
FlareSamples = 8
FlareDispersal = 0.25
FlareHaloWidth = 0.5
FlareDistortion = 1
DepthToAlpha = false
Detail = -6
RefineSteps = 4
FudgeFactor = 0.5
MaxRaySteps = 300
MaxDistance = 12
Dither = 1
NormalBackStep = 1
DetailAO = -4.5
coneApertureAO = 0.5
maxIterAO = 20
FudgeAO = 1
AO_ambient = 1
AO_camlight = 1
AO_pointlight = 1
AoCorrect = 0
Specular = 0.0833333
SpecularExp = 250
CamLight = 1,1,1,2
AmbiantLight = 1,1,1,1
Glow = 1,1,1,0
GlowMax = 233
Reflection = 0.5098039,0.5098039,0.5098039
ReflectionsNumber = 1
SpotGlow = false
SpotLight = 1,1,1,0.5
LightPos = 3.33333,0,1.42857
LightSize = 0
LightFallOff = 0
LightGlowRad = 0
LightGlowExp = 0.531915
HardShadow = 0.5
ShadowSoft = 1
BaseColor = 1,1,1
OrbitStrength = 0.5
X = 0.5,0.6,0.6,-0.5625
Y = 1,0.6,0,0.4583333
Z = 0.8,0.78,1,0.7659574
R = 0.4,0.7,1,-0.25
BackgroundColor = 0.278431,0.278431,0.419608
GradientBackground = 2.619048
CycleColors = true
Cycles = 3.2
EnableFloor = false
FloorNormal = 0,0,1
FloorHeight = 0
FloorColor = 1,1,1
HF_Fallof = 0.0005
HF_Const = 0.075
HF_Intensity = 0.70313
HF_Dir = 0,1,0
HF_Offset = 0
HF_Color = 0.145098,0,0,2.26416
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 1
HF_CastShadow = false
CloudScale = 0.72855
CloudFlatness = 0
CloudTops = 2.258
CloudBase = -1.1476
CloudDensity = 0.34483
CloudRoughness = 0.8421
CloudContrast = 10
CloudColor = 0.65,0.68,0.7
SunLightColor = 0.7,0.5,0.3
WindDir = 0,0,1
WindSpeed = 1
Bailout = 26.80412
Sphere = false
Iterations = 12
Scale = 2.235294
RotVector = 1,0,0
RotAngle = 0
Offset = 2.256637,2.964602,2.371681
fo = 0.819698,0.8521429,0.81968
g = 0.1846154,0.1846154,0.1846154
Serial = false
InvertC = 1,-2,0
#endpreset
